@@ -5,26 +5,27 @@ import pytest
 
 @pytest.fixture(scope="module")
 def inst_dir():
-    return r"C:\custom_location"
+    return "C:\\custom_location"
 
 
 @pytest.fixture(scope="module")
 def install(inst_dir):
-    pytest.helpers.clean_env(inst_dir)
-    pytest.helpers.run_command(
-        [
-            pytest.INST_BIN,
-            "/S",
-            f"/install-dir={inst_dir}",
-            "/master=cli_master",
-            "/minion-name=cli_minion",
-        ]
-    )
-    yield
+    pytest.helpers.clean_env()
+    args = [
+        "/S",
+        f"/install-dir={inst_dir}",
+        "/master=cli_master",
+        "/minion-name=cli_minion",
+    ]
+    pytest.helpers.install_salt(args)
+    yield args
     pytest.helpers.clean_env(inst_dir)
 
 
 def test_binaries_present(install, inst_dir):
+    # This will show the contents of the directory on failure
+    inst_dir_exists = os.path.exists(inst_dir)
+    dir_contents = os.listdir(inst_dir)
     assert os.path.exists(rf"{inst_dir}\ssm.exe")
 
 
