@@ -32,6 +32,7 @@
 import pytest
 
 from tests.support.case import SSHCase
+from tests.support.helpers import system_python_version
 
 pytestmark = [
     pytest.mark.skip_on_windows,
@@ -43,6 +44,10 @@ pytestmark = [
         # has been deprecated since Python 3.7, so, the logic goes into trying to import
         # backports.ssl-match-hostname which is not installed on the system.
     ),
+    pytest.mark.skipif(
+        system_python_version() < (3, 10),
+        reason="System python too old for these tests",
+    ),
 ]
 
 
