@@ -223,9 +223,9 @@ def test_list_groups_int(user, account_int):
     assert ret == ["Users"]
 
 
-def test_list_users(user):
+def test_list_users(user, account_str):
     ret = user.list_users()
-    assert "Administrator" in ret
+    assert account_str.username in ret
 
 
 def test_removegroup_str(user, account_str):
