@@ -16,9 +16,9 @@ def test__get_ip_base_properties():
     interfaces = win_network._get_network_interfaces()
     for interface in interfaces:
         base_properties = win_network._get_ip_base_properties(interface)
-        assert "dhcp_enabled" in base_properties
-        assert "forwarding_enabled" in base_properties
-        assert "wins_enabled" in base_properties
+        assert "ipv4_dhcp_enabled" in base_properties
+        assert "ipv4_forwarding_enabled" in base_properties
+        assert "ipv4_wins_enabled" in base_properties
 
 
 def test_get_interface_info_dot_net_formatted():
@@ -27,4 +27,4 @@ def test_get_interface_info_dot_net_formatted():
         assert "description" in interfaces[interface]
         assert "hwaddr" in interfaces[interface]
         assert "up" in interfaces[interface]
-        assert "dhcp_enabled" in interfaces[interface]
+        assert "dhcp_enabled" in interfaces[interface]["inet"][0]
