@@ -10,6 +10,7 @@ from pytestshellutils.exceptions import FactoryNotStarted
 from saltfactories.utils import random_string
 
 import salt.defaults.exitcodes
+from tests.conftest import FIPS_TESTRUN
 from tests.support.helpers import PRE_PYTEST_SKIP_REASON
 
 log = logging.getLogger(__name__)
@@ -51,7 +52,15 @@ def test_exit_status_no_proxyid(salt_master, proxy_minion_id):
 
     with pytest.raises(FactoryNotStarted) as exc:
         factory = salt_master.salt_proxy_minion_daemon(
-            proxy_minion_id, include_proxyid_cli_flag=False, defaults=config_defaults
+            proxy_minion_id,
+            include_proxyid_cli_flag=False,
+            defaults=config_defaults,
+            overrides={
+                "fips_mode": FIPS_TESTRUN,
+                "publish_signing_algorithm": (
+                    "PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1"
+                ),
+            },
         )
         factory.start(start_timeout=10, max_start_attempts=1)
 
@@ -73,8 +82,15 @@ def test_exit_status_unknown_user(salt_master, proxy_minion_id):
     with pytest.raises(FactoryNotStarted) as exc:
         factory = salt_master.salt_proxy_minion_daemon(
             proxy_minion_id,
-            overrides={"user": "unknown-user"},
             defaults=config_defaults,
+            overrides={
+                "user": "unknown-user",
+                "fips_mode": FIPS_TESTRUN,
+                "encryption_algorithm": "OAEP-SHA224" if FIPS_TESTRUN else "OAEP-SHA1",
+                "signing_algorithm": (
+                    "PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1"
+                ),
+            },
         )
         factory.start(start_timeout=10, max_start_attempts=1)
 
@@ -93,7 +109,15 @@ def test_exit_status_unknown_argument(salt_master, proxy_minion_id):
 
     with pytest.raises(FactoryNotStarted) as exc:
         factory = salt_master.salt_proxy_minion_daemon(
-            proxy_minion_id, defaults=config_defaults
+            proxy_minion_id,
+            defaults=config_defaults,
+            overrides={
+                "fips_mode": FIPS_TESTRUN,
+                "encryption_algorithm": "OAEP-SHA224" if FIPS_TESTRUN else "OAEP-SHA1",
+                "signing_algorithm": (
+                    "PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1"
+                ),
+            },
         )
         factory.start("--unknown-argument", start_timeout=10, max_start_attempts=1)
 
@@ -129,6 +153,11 @@ def test_exit_status_correct_usage(
     config_defaults = {
         "metaproxy": "deltaproxy",
     }
+    config_overrides = {
+        "fips_mode": FIPS_TESTRUN,
+        "encryption_algorithm": "OAEP-SHA224" if FIPS_TESTRUN else "OAEP-SHA1",
+        "signing_algorithm": "PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1",
+    }
     proxy_one = "dummy_proxy_one"
     proxy_two = "dummy_proxy_two"
 
@@ -184,6 +213,7 @@ def test_exit_status_correct_usage(
         factory = salt_master.salt_proxy_minion_daemon(
             proxy_minion_id,
             defaults=config_defaults,
+            overrides=config_overrides,
             extra_cli_arguments_after_first_start_failure=["--log-level=info"],
             start_timeout=320,
         )
@@ -246,6 +276,11 @@ def test_missing_pillar_file(
     config_defaults = {
         "metaproxy": "deltaproxy",
     }
+    config_overrides = {
+        "fips_mode": FIPS_TESTRUN,
+        "encryption_algorithm": "OAEP-SHA224" if FIPS_TESTRUN else "OAEP-SHA1",
+        "signing_algorithm": "PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1",
+    }
     proxy_one = "dummy_proxy_one"
     proxy_two = "dummy_proxy_two"
 
@@ -287,6 +322,7 @@ def test_missing_pillar_file(
         factory = salt_master.salt_proxy_minion_daemon(
             proxy_minion_id,
             defaults=config_defaults,
+            overrides=config_overrides,
             extra_cli_arguments_after_first_start_failure=["--log-level=info"],
             start_timeout=320,
         )
@@ -344,6 +380,11 @@ def test_invalid_connection(
     config_defaults = {
         "metaproxy": "deltaproxy",
     }
+    config_overrides = {
+        "fips_mode": FIPS_TESTRUN,
+        "encryption_algorithm": "OAEP-SHA224" if FIPS_TESTRUN else "OAEP-SHA1",
+        "signing_algorithm": "PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1",
+    }
     proxy_one = "dummy_proxy_one"
     broken_proxy_one = "broken_proxy_one"
     broken_proxy_two = "broken_proxy_two"
@@ -415,6 +456,7 @@ def test_invalid_connection(
         factory = salt_master.salt_proxy_minion_daemon(
             proxy_minion_id,
             defaults=config_defaults,
+            overrides=config_overrides,
             extra_cli_arguments_after_first_start_failure=["--log-level=info"],
             start_timeout=320,
         )
@@ -474,6 +516,11 @@ def test_custom_proxy_module(
     config_defaults = {
         "metaproxy": "deltaproxy",
     }
+    config_overrides = {
+        "fips_mode": FIPS_TESTRUN,
+        "encryption_algorithm": "OAEP-SHA224" if FIPS_TESTRUN else "OAEP-SHA1",
+        "signing_algorithm": "PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1",
+    }
     proxy_one = "custom_dummy_proxy_one"
     proxy_two = "custom_dummy_proxy_two"
 
@@ -548,6 +595,7 @@ def ping():
         factory = salt_master.salt_proxy_minion_daemon(
             proxy_minion_id,
             defaults=config_defaults,
+            overrides=config_overrides,
             extra_cli_arguments_after_first_start_failure=["--log-level=info"],
             start_timeout=320,
         )
@@ -611,6 +659,11 @@ def test_custom_proxy_module_raise_exception(
     config_defaults = {
         "metaproxy": "deltaproxy",
     }
+    config_overrides = {
+        "fips_mode": FIPS_TESTRUN,
+        "encryption_algorithm": "OAEP-SHA224" if FIPS_TESTRUN else "OAEP-SHA1",
+        "signing_algorithm": "PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1",
+    }
     proxy_one = "custom_dummy_proxy_one"
     proxy_two = "custom_dummy_proxy_two"
 
@@ -685,6 +738,7 @@ def ping():
         factory = salt_master.salt_proxy_minion_daemon(
             proxy_minion_id,
             defaults=config_defaults,
+            overrides=config_overrides,
             extra_cli_arguments_after_first_start_failure=["--log-level=info"],
             start_timeout=320,
         )
@@ -750,6 +804,11 @@ def test_exit_status_correct_usage_large_number_of_minions(
     config_defaults = {
         "metaproxy": "deltaproxy",
     }
+    config_overrides = {
+        "fips_mode": FIPS_TESTRUN,
+        "encryption_algorithm": "OAEP-SHA224" if FIPS_TESTRUN else "OAEP-SHA1",
+        "signing_algorithm": "PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1",
+    }
     sub_proxies = [
         "proxy_one",
         "proxy_two",
@@ -826,6 +885,7 @@ def test_exit_status_correct_usage_large_number_of_minions(
         factory = salt_master.salt_proxy_minion_daemon(
             proxy_minion_id,
             defaults=config_defaults,
+            overrides=config_overrides,
             extra_cli_arguments_after_first_start_failure=["--log-level=info"],
             start_timeout=320,
         )
