@@ -108,8 +108,10 @@ def test_grains_append_val_is_list(salt_call_cli, append_grain):
 
 @pytest.mark.timeout_unless_on_windows(300)
 def test_grains_remove_add(
-    salt_call_cli, append_grain, wait_for_pillar_refresh_complete
+    salt_call_cli, append_grain, wait_for_pillar_refresh_complete, grains
 ):
+    if grains["os"] == "Fedora" and grains["osmajorrelease"] >= 40:
+        pytest.skip(f"Temporary skip on {grains['osfinger']}")
     second_grain = append_grain.value + "-2"
     ret = salt_call_cli.run("grains.get", append_grain.key)
     assert ret.returncode == 0
