@@ -4,7 +4,11 @@ import pytest
 
 import salt.netapi
 from salt.exceptions import EauthAuthenticationError, SaltInvocationError
-from tests.support.helpers import SaveRequestsPostHandler, Webserver
+from tests.support.helpers import (
+    SaveRequestsPostHandler,
+    Webserver,
+    system_python_version,
+)
 from tests.support.mock import patch
 
 pytestmark = [
@@ -18,6 +22,10 @@ pytestmark = [
         # has been deprecated since Python 3.7, so, the logic goes into trying to import
         # backports.ssl-match-hostname which is not installed on the system.
     ),
+    pytest.mark.skipif(
+        system_python_version() < (3, 10),
+        reason="System python too old for these tests",
+    ),
     pytest.mark.timeout_unless_on_windows(120),
 ]
 
