@@ -68,7 +68,7 @@ def ssh_docker_container(salt_factories, ssh_keys):
                 "SSH_USER": "centos",
                 "SSH_AUTHORIZED_KEYS": ssh_keys.pub,
             },
-            "cap_add": "IPC_LOCK",
+            "cap_add": ["IPC_LOCK"],
         },
         pull_before_start=True,
         skip_on_pull_failure=True,
