@@ -7,8 +7,10 @@ import logging
 import os
 import pathlib
 import shutil
+import time
 
 import packaging.version
+import psutil
 import pytest
 from pytestskipmarkers.utils import platform
 
@@ -53,33 +55,10 @@ def get_salt_test_commands():
 
 @pytest.fixture(scope="module")
 def root_url(salt_release):
-    if os.environ.get("SALT_REPO_TYPE", "release") == "staging":
-        repo_domain = os.environ.get(
-            "SALT_REPO_DOMAIN_STAGING", "staging.repo.saltproject.io"
-        )
-    else:
-        repo_domain = os.environ.get("SALT_REPO_DOMAIN_RELEASE", "repo.saltproject.io")
-    if "rc" in salt_release:
-        salt_path = "salt_rc/salt"
-    else:
-        salt_path = "salt"
-    salt_repo_user = os.environ.get("SALT_REPO_USER")
-    if salt_repo_user:
-        log.info(
-            "SALT_REPO_USER: %s",
-            salt_repo_user[0] + "*" * (len(salt_repo_user) - 2) + salt_repo_user[-1],
-        )
-    salt_repo_pass = os.environ.get("SALT_REPO_PASS")
-    if salt_repo_pass:
-        log.info(
-            "SALT_REPO_PASS: %s",
-            salt_repo_pass[0] + "*" * (len(salt_repo_pass) - 2) + salt_repo_pass[-1],
-        )
-    if salt_repo_user and salt_repo_pass:
-        repo_domain = f"{salt_repo_user}:{salt_repo_pass}@{repo_domain}"
-    _root_url = f"https://{repo_domain}/{salt_path}/py3"
-    log.info("Repository Root URL: %s", _root_url)
-    return _root_url
+    default_url = "https://packages.broadcom.com/artifactory"
+    repo_domain = os.environ.get("SALT_REPO_DOMAIN_RELEASE", default_url)
+    log.info("Repository Root URL: %s", repo_domain)
+    return repo_domain
 
 
 @pytest.fixture(scope="module")
@@ -93,46 +72,15 @@ def get_salt_release():
     if salt_release is None:
         if pkg_test_type == "download-pkgs":
             log.warning(
-                "Setting salt release to 3006.0rc2 which is probably not what you want."
+                "Setting salt release to 3006.0 which is probably not what you want."
             )
-        salt_release = "3006.0rc2"
+        salt_release = "3006.0"
     if pkg_test_type == "download-pkgs":
-        if packaging.version.parse(salt_release) < packaging.version.parse("3006.0rc1"):
+        if packaging.version.parse(salt_release) < packaging.version.parse("3006.0"):
             log.warning("The salt release being tested, %r looks off.", salt_release)
     return salt_release
 
 
-def get_repo_subpath_params():
-    current_release = packaging.version.parse(get_salt_release())
-    params = ["minor", current_release.major]
-    latest_env_var = os.environ.get("LATEST_SALT_RELEASE")
-    if latest_env_var is not None:
-        latest_release = packaging.version.parse(latest_env_var)
-        if current_release >= latest_release:
-            log.debug(
-                "Running the tests for the latest release since %s >= %s",
-                current_release,
-                latest_release,
-            )
-            params.append("latest")
-    return params
-
-
-@pytest.fixture(
-    scope="module",
-    params=get_repo_subpath_params(),
-)
-def repo_subpath(request):
-    return request.param
-
-
-@pytest.fixture(scope="module")
-def gpg_key_name(salt_release):
-    if packaging.version.parse(salt_release) > packaging.version.parse("3005"):
-        return "SALT-PROJECT-GPG-PUBKEY-2023.pub"
-    return "salt-archive-keyring.gpg"
-
-
 @pytest.fixture(scope="module")
 def salt_release():
     yield get_salt_release()
@@ -151,8 +99,6 @@ def _setup_system(
     shell,
     root_url,
     salt_release,
-    gpg_key_name,
-    repo_subpath,
     package_type,
     tmp_path_factory,
     onedir_install_path,
@@ -166,7 +112,6 @@ def _setup_system(
                 root_url=root_url,
                 salt_release=salt_release,
                 downloads_path=downloads_path,
-                repo_subpath=repo_subpath,
                 package_type=package_type,
                 onedir_install_path=onedir_install_path,
             ):
@@ -178,7 +123,6 @@ def _setup_system(
                     root_url=root_url,
                     salt_release=salt_release,
                     downloads_path=downloads_path,
-                    repo_subpath=repo_subpath,
                     package_type=package_type,
                     onedir_install_path=onedir_install_path,
                 )
@@ -190,8 +134,6 @@ def _setup_system(
                     root_url=root_url,
                     salt_release=salt_release,
                     downloads_path=downloads_path,
-                    gpg_key_name=gpg_key_name,
-                    repo_subpath=repo_subpath,
                 )
             elif grains["os"] == "Fedora":
                 setup_redhat_family(
@@ -201,8 +143,6 @@ def _setup_system(
                     root_url=root_url,
                     salt_release=salt_release,
                     downloads_path=downloads_path,
-                    gpg_key_name=gpg_key_name,
-                    repo_subpath=repo_subpath,
                 )
             elif grains["os"] == "VMware Photon OS":
                 setup_redhat_family(
@@ -212,8 +152,6 @@ def _setup_system(
                     root_url=root_url,
                     salt_release=salt_release,
                     downloads_path=downloads_path,
-                    gpg_key_name=gpg_key_name,
-                    repo_subpath=repo_subpath,
                 )
             elif grains["os_family"] == "RedHat":
                 setup_redhat_family(
@@ -223,20 +161,14 @@ def _setup_system(
                     root_url=root_url,
                     salt_release=salt_release,
                     downloads_path=downloads_path,
-                    gpg_key_name=gpg_key_name,
-                    repo_subpath=repo_subpath,
                 )
             elif grains["os_family"] == "Debian":
                 setup_debian_family(
                     shell,
-                    os_name=grains["os"].lower(),
-                    os_version=grains["osrelease"],
                     os_codename=grains["oscodename"],
                     root_url=root_url,
                     salt_release=salt_release,
                     downloads_path=downloads_path,
-                    gpg_key_name=gpg_key_name,
-                    repo_subpath=repo_subpath,
                     package_type=package_type,
                     onedir_install_path=onedir_install_path,
                 )
@@ -254,34 +186,19 @@ def setup_redhat_family(
     root_url,
     salt_release,
     downloads_path,
-    gpg_key_name,
-    repo_subpath,
 ):
     arch = os.environ.get("SALT_REPO_ARCH") or "x86_64"
 
     if os_name == "photon":
         os_version = f"{os_version}.0"
 
-    if repo_subpath == "minor":
-        repo_url_base = (
-            f"{root_url}/{os_name}/{os_version}/{arch}/{repo_subpath}/{salt_release}"
-        )
-    else:
-        repo_url_base = f"{root_url}/{os_name}/{os_version}/{arch}/{repo_subpath}"
-
-    gpg_file_url = f"{root_url}/{os_name}/{os_version}/{arch}/{gpg_key_name}"
-
-    try:
-        pytest.helpers.download_file(gpg_file_url, downloads_path / gpg_key_name)
-    except Exception as exc:  # pylint: disable=broad-except
-        pytest.fail(f"Failed to download {gpg_file_url}: {exc}")
-
-    ret = shell.run("rpm", "--import", str(downloads_path / gpg_key_name), check=False)
-    if ret.returncode != 0:
-        pytest.fail("Failed to import gpg key")
+    repo_url_base = f"{root_url}/saltproject-rpm"
 
+    # Download the salt.repo
+    # It contains the gpg key url so we don't need to download it here
+    salt_repo_url = "https://github.com/saltstack/salt-install-guide/releases/latest/download/salt.repo"
     repo_file = pytest.helpers.download_file(
-        f"{repo_url_base}.repo", downloads_path / f"salt-{os_name}.repo"
+        salt_repo_url, downloads_path / "salt.repo"
     )
 
     commands = [
@@ -291,13 +208,13 @@ def setup_redhat_family(
             "yum",
             "install",
             "-y",
-            "salt-master",
-            "salt-minion",
-            "salt-ssh",
-            "salt-syndic",
-            "salt-cloud",
-            "salt-api",
-            "salt-debuginfo",
+            f"salt-master-{salt_release}",
+            f"salt-minion-{salt_release}",
+            f"salt-ssh-{salt_release}",
+            f"salt-syndic-{salt_release}",
+            f"salt-cloud-{salt_release}",
+            f"salt-api-{salt_release}",
+            f"salt-debuginfo-{salt_release}",
         ),
     ]
 
@@ -309,14 +226,10 @@ def setup_redhat_family(
 
 def setup_debian_family(
     shell,
-    os_name,
-    os_version,
     os_codename,
     root_url,
     salt_release,
     downloads_path,
-    gpg_key_name,
-    repo_subpath,
     package_type,
     onedir_install_path,
 ):
@@ -331,11 +244,9 @@ def setup_debian_family(
         elif arch == "x86_64":
             arch = "amd64"
 
-        if repo_subpath == "minor":
-            repo_url_base = f"{root_url}/{os_name}/{os_version}/{arch}/{repo_subpath}/{salt_release}"
-        else:
-            repo_url_base = f"{root_url}/{os_name}/{os_version}/{arch}/{repo_subpath}"
-        gpg_file_url = f"{root_url}/{os_name}/{os_version}/{arch}/{gpg_key_name}"
+        repo_url_base = f"{root_url}/saltproject-deb/"
+        gpg_file_url = "https://packages.broadcom.com/artifactory/api/security/keypair/SaltProjectKey/public"
+        gpg_key_name = "SALT-PROJECT-GPG-PUBKEY-2023.pub"
 
         try:
             pytest.helpers.download_file(gpg_file_url, downloads_path / gpg_key_name)
@@ -380,11 +291,9 @@ def setup_debian_family(
     else:
         # We are testing the onedir download
         onedir_name = f"salt-{salt_release}-onedir-linux-{arch}.tar.xz"
-        if repo_subpath == "minor":
-            repo_url_base = f"{root_url}/onedir/{repo_subpath}/{salt_release}"
-        else:
-            repo_url_base = f"{root_url}/onedir/{repo_subpath}"
-        onedir_url = f"{repo_url_base}/{onedir_name}"
+        onedir_url = (
+            f"{root_url}/saltproject-generic/onedir/{salt_release}/{onedir_name}"
+        )
         onedir_location = downloads_path / onedir_name
         onedir_extracted = onedir_install_path
 
@@ -401,24 +310,13 @@ def setup_macos(
     root_url,
     salt_release,
     downloads_path,
-    repo_subpath,
     package_type,
     onedir_install_path,
 ):
     arch = os.environ.get("SALT_REPO_ARCH") or "x86_64"
     if package_type == "package":
-
-        if packaging.version.parse(salt_release) > packaging.version.parse("3005"):
-            mac_pkg = f"salt-{salt_release}-py3-{arch}.pkg"
-            if repo_subpath == "minor":
-                mac_pkg_url = (
-                    f"{root_url}/macos/{repo_subpath}/{salt_release}/{mac_pkg}"
-                )
-            else:
-                mac_pkg_url = f"{root_url}/macos/{repo_subpath}/{mac_pkg}"
-        else:
-            mac_pkg_url = f"{root_url}/macos/{salt_release}/{mac_pkg}"
-            mac_pkg = f"salt-{salt_release}-macos-{arch}.pkg"
+        mac_pkg = f"salt-{salt_release}-py3-{arch}.pkg"
+        mac_pkg_url = f"{root_url}/saltproject-generic/macos/{salt_release}/{mac_pkg}"
 
         mac_pkg_path = downloads_path / mac_pkg
         pytest.helpers.download_file(mac_pkg_url, mac_pkg_path)
@@ -435,11 +333,7 @@ def setup_macos(
     else:
         # We are testing the onedir download
         onedir_name = f"salt-{salt_release}-onedir-macos-{arch}.tar.xz"
-        if repo_subpath == "minor":
-            repo_url_base = f"{root_url}/onedir/{repo_subpath}/{salt_release}"
-        else:
-            repo_url_base = f"{root_url}/onedir/{repo_subpath}"
-        onedir_url = f"{repo_url_base}/{onedir_name}"
+        onedir_url = f"{root_url}/onedir/{salt_release}/{onedir_name}"
         onedir_location = downloads_path / onedir_name
         onedir_extracted = onedir_install_path
 
@@ -457,40 +351,71 @@ def setup_windows(
     root_url,
     salt_release,
     downloads_path,
-    repo_subpath,
     package_type,
     onedir_install_path,
+    timeout=300,
 ):
     try:
         arch = os.environ.get("SALT_REPO_ARCH") or "amd64"
         if package_type != "onedir":
             root_dir = pathlib.Path(os.getenv("ProgramFiles"), "Salt Project", "Salt")
 
-            if packaging.version.parse(salt_release) > packaging.version.parse("3005"):
-                if package_type.lower() == "nsis":
-                    if arch.lower() != "x86":
-                        arch = arch.upper()
-                    win_pkg = f"Salt-Minion-{salt_release}-Py3-{arch}-Setup.exe"
-                else:
-                    if arch.lower() != "x86":
-                        arch = arch.upper()
-                    win_pkg = f"Salt-Minion-{salt_release}-Py3-{arch}.msi"
-                if repo_subpath == "minor":
-                    win_pkg_url = (
-                        f"{root_url}/windows/{repo_subpath}/{salt_release}/{win_pkg}"
-                    )
-                else:
-                    win_pkg_url = f"{root_url}/windows/{repo_subpath}/{win_pkg}"
-                ssm_bin = root_dir / "ssm.exe"
+            if package_type.lower() == "nsis":
+                if arch.lower() != "x86":
+                    arch = arch.upper()
+                win_pkg = f"Salt-Minion-{salt_release}-Py3-{arch}-Setup.exe"
             else:
-                win_pkg = f"salt-{salt_release}-windows-{arch}.exe"
-                win_pkg_url = f"{root_url}/windows/{salt_release}/{win_pkg}"
-                ssm_bin = root_dir / "bin" / "ssm_bin"
+                if arch.lower() != "x86":
+                    arch = arch.upper()
+                win_pkg = f"Salt-Minion-{salt_release}-Py3-{arch}.msi"
+            win_pkg_url = (
+                f"{root_url}/saltproject-generic/windows/{salt_release}/{win_pkg}"
+            )
+            ssm_bin = root_dir / "ssm.exe"
 
             pkg_path = downloads_path / win_pkg
 
             pytest.helpers.download_file(win_pkg_url, pkg_path)
             if package_type.lower() == "nsis":
+                # We need to make sure there are no installer/uninstaller
+                # processes running. Uninst.exe launches a 2nd binary
+                # (Un.exe or Un_*.exe) Let's get the name of the process
+                processes = [
+                    win_pkg,
+                    "uninst.exe",
+                    "Un.exe",
+                    "Un_A.exe",
+                    "Un_B.exe",
+                    "Un_C.exe",
+                    "Un_D.exe",
+                    "Un_D.exe",
+                    "Un_F.exe",
+                    "Un_G.exe",
+                ]
+                proc_name = ""
+                for proc in processes:
+                    try:
+                        if proc in (p.name() for p in psutil.process_iter()):
+                            proc_name = proc
+                    except psutil.NoSuchProcess:
+                        continue
+
+                # We need to give the process time to exit. We'll timeout after
+                # 5 minutes or whatever timeout is set to
+                if proc_name:
+                    elapsed_time = 0
+                    while elapsed_time < timeout:
+                        try:
+                            if proc_name not in (
+                                p.name() for p in psutil.process_iter()
+                            ):
+                                break
+                        except psutil.NoSuchProcess:
+                            continue
+                        elapsed_time += 0.1
+                        time.sleep(0.1)
+
+                # Only run setup when we're sure no other installations are running
                 ret = shell.run(str(pkg_path), "/start-minion=0", "/S", check=False)
             else:
                 ret = shell.run(
@@ -512,11 +437,7 @@ def setup_windows(
         else:
             # We are testing the onedir download
             onedir_name = f"salt-{salt_release}-onedir-windows-{arch}.zip"
-            if repo_subpath == "minor":
-                repo_url_base = f"{root_url}/onedir/{repo_subpath}/{salt_release}"
-            else:
-                repo_url_base = f"{root_url}/onedir/{repo_subpath}"
-            onedir_url = f"{repo_url_base}/{onedir_name}"
+            onedir_url = f"{root_url}/onedir/{salt_release}/{onedir_name}"
             onedir_location = downloads_path / onedir_name
             onedir_extracted = onedir_install_path
 
@@ -556,6 +477,7 @@ def salt_test_command(request, install_dir):
     return command
 
 
+@pytest.mark.skip_on_windows(reason="This is flaky on Windows")
 @pytest.mark.parametrize("salt_test_command", get_salt_test_commands(), indirect=True)
 def test_download(shell, salt_test_command):
     """
