@@ -1,9 +1,9 @@
 import textwrap
+from collections import OrderedDict
 
 import pytest
 
 import salt.modules.pkgng as pkgng
-from salt.utils.odict import OrderedDict
 from tests.support.mock import MagicMock, patch
 
 
