@@ -2,10 +2,10 @@
     :codeauthor: Alexander Schwartz <alexander.schwartz@gmx.net>
 """
 
-
 import os
 
 import pytest
+
 import salt.states.archive as archive
 import salt.utils.platform
 from tests.support.mock import MagicMock, patch
@@ -54,8 +54,8 @@ def test_extracted_tar():
     """
 
     if salt.utils.platform.is_windows():
-        source = "c:\\tmp\\foo.tar.gz"
-        tmp_dir = "c:\\tmp\\test_extracted_tar"
+        source = "C:\\tmp\\foo.tar.gz"
+        tmp_dir = "C:\\tmp\\test_extracted_tar"
     elif salt.utils.platform.is_darwin():
         source = "/private/tmp/foo.tar.gz"
         tmp_dir = "/private/tmp/test_extracted_tar"
@@ -101,7 +101,8 @@ def test_extracted_tar():
     isfile_mock = MagicMock(side_effect=_isfile_side_effect)
 
     with patch.dict(
-        archive.__opts__, {"test": False, "cachedir": tmp_dir, "hash_type": "sha256"},
+        archive.__opts__,
+        {"test": False, "cachedir": tmp_dir, "hash_type": "sha256"},
     ), patch.dict(
         archive.__salt__,
         {
@@ -303,7 +304,7 @@ def test_extracted_when_if_missing_path_exists():
     with patch.object(os.path, "exists", MagicMock(return_value=True)):
         ret = archive.extracted(name, source=source, if_missing=if_missing)
         assert ret["result"], ret
-        assert ret["comment"] == "Path {} exists".format(if_missing)
+        assert ret["comment"] == f"Path {if_missing} exists"
 
 
 def test_clean_parent_conflict():
@@ -429,8 +430,8 @@ def test_skip_files_list_verify_success():
     """
 
     if salt.utils.platform.is_windows():
-        source = "c:\\tmp\\foo.tar.gz"
-        tmp_dir = "c:\\tmp\\test_extracted_tar"
+        source = "C:\\tmp\\foo.tar.gz"
+        tmp_dir = "C:\\tmp\\test_extracted_tar"
     elif salt.utils.platform.is_darwin():
         source = "/private/tmp/foo.tar.gz"
         tmp_dir = "/private/tmp/test_extracted_tar"
@@ -451,7 +452,7 @@ def test_skip_files_list_verify_success():
     }
     mock_true = MagicMock(return_value=True)
     mock_false = MagicMock(return_value=False)
-    mock_cached = MagicMock(return_value="{}/{}".format(tmp_dir, source))
+    mock_cached = MagicMock(return_value=f"{tmp_dir}/{source}")
     source_sum = {"hsum": "testhash", "hash_type": "sha256"}
     mock_hash = MagicMock(return_value=source_sum)
     mock_source_list = MagicMock(return_value=(source, None))
