@@ -48,9 +48,15 @@ def mock_ip_base():
             "dns_enabled": False,
             "dns_suffix": "",
             "dynamic_dns_enabled": False,
-            "dhcp_enabled": False,
-            "forwarding_enabled": False,
-            "wins_enabled": False,
+            "ipv4_apipa_active": False,
+            "ipv4_apipa_enabled": True,
+            "ipv4_dhcp_enabled": False,
+            "ipv4_forwarding_enabled": False,
+            "ipv4_index": 1,
+            "ipv4_mtu": 1500,
+            "ipv4_wins_enabled": False,
+            "ipv6_index": 1,
+            "ipv6_mtu": 1500,
         }
     )
 
@@ -151,11 +157,9 @@ def test_get_interface_info_dot_net(
         "Ethernet": {
             "alias": "Ethernet",
             "description": "Dell GigabitEthernet",
-            "dhcp_enabled": False,
             "dns_enabled": False,
             "dns_suffix": "",
             "dynamic_dns_enabled": False,
-            "forwarding_enabled": False,
             "id": "{C5F468C0-DD5F-4C2B-939F-A411DCB5DE16}",
             "ip_addresses": [
                 {
@@ -180,6 +184,13 @@ def test_get_interface_info_dot_net(
                 "239.255.255.250",
             ],
             "ip_wins": [],
+            "ipv4_apipa_active": False,
+            "ipv4_apipa_enabled": True,
+            "ipv4_dhcp_enabled": False,
+            "ipv4_forwarding_enabled": False,
+            "ipv4_index": 1,
+            "ipv4_mtu": 1500,
+            "ipv4_wins_enabled": False,
             "ipv6_addresses": [
                 {
                     "address": "fe80::e8a4:1224:5548:2b81",
@@ -192,6 +203,8 @@ def test_get_interface_info_dot_net(
             "ipv6_anycast": [],
             "ipv6_dns": ["2600:740a:1:304::1"],
             "ipv6_gateways": ["fe80::208:a2ff:fe0b:de70"],
+            "ipv6_index": 1,
+            "ipv6_mtu": 1500,
             "ipv6_multicast": [
                 "ff01::1",
                 "ff02::1",
@@ -205,7 +218,6 @@ def test_get_interface_info_dot_net(
             "receive_only": False,
             "status": "Up",
             "type": "Ethernet",
-            "wins_enabled": False,
         }
     }
 
@@ -241,21 +253,28 @@ def test_get_network_info(
     expected = {
         "Ethernet": {
             "description": "Dell GigabitEthernet",
-            "dhcp_enabled": False,
             "hwaddr": "02:D5:F1:DD:31:E0",
             "inet": [
                 {
                     "address": "172.18.87.49",
+                    "apipa_active": False,
+                    "apipa_enabled": True,
                     "broadcast": "172.18.87.63",
+                    "dhcp_enabled": False,
+                    "forwarding_enabled": False,
                     "gateway": "192.168.0.1",
-                    "label": "Ethernet",
+                    "index": 1,
+                    "mtu": 1500,
                     "netmask": "255.255.255.240",
+                    "wins_enabled": False,
                 }
             ],
             "inet6": [
                 {
                     "address": "fe80::e8a4:1224:5548:2b81",
                     "gateway": "fe80::208:a2ff:fe0b:de70",
+                    "index": 1,
+                    "mtu": 1500,
                     "prefixlen": 64,
                 }
             ],
