@@ -11,6 +11,9 @@ from tests.support.runtests import RUNTIME_VARS
 from tests.unit.modules.test_zcbuildout import KNOWN_VIRTUALENV_BINARY_NAMES, Base
 
 pytestmark = [
+    pytest.mark.skip(
+        reason="Buildout no longer supports v2 or lower, resources removed"
+    ),
     pytest.mark.skip_on_fips_enabled_platform,
     pytest.mark.skip_on_windows(
         reason=(
